# Initialization framework for Blender extensions

![logo](https://raw.githubusercontent.com/ivan-perevala/lib_bhqmain/main/.github/images/logo-dark.svg)

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

See [./LICENSE](./LICENSE) file for license.

© 2024-2025 Ivan Perevala (ivan95perevala@gmail.com)
